@@ -240,19 +240,19 @@ class MaemoPackage(object):
         files=[]
         CURRENT = os.path.dirname(sys.argv[0])
         for path in paths:
-            print CURRENT,path
-            #tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,os.path.dirname(self.__files[path][0])), path)
-            #tarinfo.uid = UID_ROOT
-            #tarinfo.gid = GID_ROOT
-            #tarinfo.uname = ""
-            #tarinfo.gname = ""                    
-            #tarOutput.addfile(tarinfo)
+            print '0:',CURRENT,path,os.path.join(CURRENT)
+            tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT), path)
+            tarinfo.uid = UID_ROOT
+            tarinfo.gid = GID_ROOT
+            tarinfo.uname = ""
+            tarinfo.gname = ""                    
+            tarOutput.addfile(tarinfo)
             
                
             
             for pfile,nfile in self.__files[path]:
                 rfile=os.path.normpath( os.path.join(path,nfile) )
-                print pfile, nfile, rfile, path
+                #print pfile, nfile, rfile, path
                 #rfile=os.path.join(path,nfile)
                 if os.path.dirname(rfile)==path:
 #                    tarinfo = tarOutput.gettarinfo(os.path.join(os.path.dirname(sys.argv[0]),rfile), os.path.dirname(os.path.join(os.path.dirname(sys.argv[0]),rfile)))
@@ -265,18 +265,20 @@ class MaemoPackage(object):
 #                    tarinfo.size = len(content.getvalue())
 
 #                    tarinfo.gname = ""
-#                    print '1:',os.path.join(path,pfile),(os.path.join(os.path.dirname(sys.argv[0]),pfile))
+                    print '1:',os.path.join(path,pfile),(os.path.join(os.path.dirname(sys.argv[0]),pfile))
                     tarOutput.addfilefromstring(os.path.join(path,pfile),file(os.path.join(os.path.dirname(sys.argv[0]),pfile)).read())
 #                    tarOutput.addfile(tarinfo, file(os.path.join(os.path.dirname(sys.argv[0]),pfile)))
 #                    print file(os.path.join(os.path.dirname(sys.argv[0]),pfile)).read()
 #                    tarOutput.addfile(tarinfo, file(pfile))
                 else:
                     print '2:',path,pfile,nfile,rfile,os.path.dirname(sys.argv[0])
-                    tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,os.path.dirname(pfile)), path)
+                    print '3:',os.path.join(CURRENT,os.path.dirname(pfile)), os.path.join(path,os.path.dirname(pfile))
+                    tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,os.path.dirname(pfile)), os.path.join(path,os.path.dirname(pfile)))
                     tarinfo.uid = UID_ROOT
                     tarinfo.gid = GID_ROOT
                     tarinfo.uname = ""
-                    tarinfo.gname = ""                    
+                    tarinfo.gname = ""
+                    tarinfo.mtime = int(time.time())                    
                     tarOutput.addfile(tarinfo)            
 
                     tarinfo = tarOutput.gettarinfo(os.path.join(CURRENT,pfile), rfile)
